Installation
============

There are several options for installing GEOUNED package.
The installation selected has implications for how you run GEOUNED Python scripts.
Currently the Mamba / Conda install is the recommended method.
The main complication when installing GEOUNED is integration between the main dependency (FreeCAD) and the users system Python.
Mamba / Conda provides a connection between the FreeCAD Python library and your system Python.
Users have also had success installing FreeCAD and making use of the Python version inbuilt into FreeCAD and the freecad.cmd however the integration of FrreCAD with the system Python is more challenging when installing in this manner.


.. toctree::
   :maxdepth: 1

   install_linux
   install_windows